@@ -103,6 +103,7 @@ class MEState(object):
               MPSetting('legend2', str, 'upper right', 'legend2 position'),
               MPSetting('title', str, None, 'Graph title'),
               MPSetting('debug', int, 0, 'debug level'),
+              MPSetting('paramdocs', bool, True, 'show param docs'),
               ]
             )
 
@@ -766,6 +767,56 @@ def cmd_messages(args):
             print("%s %s" % (timestring(m), mstr))
     mestate.mlog.rewind()
 
+def extract_files():
+    '''extract all FILE messages as a dictionary of files'''
+    sequences = {}
+    mestate.mlog.rewind()
+    while True:
+        m = mestate.mlog.recv_match(type=['FILE'], condition=mestate.settings.condition)
+        if m is None:
+            break
+        if not m.FileName in sequences:
+            sequences[m.FileName] = set()
+        sequences[m.FileName].add((m.Offset, m.Data[:m.Length]))
+    ret = {}
+    for f in sequences:
+        ofs = 0
+        seen = set()
+        seq = sorted(list(sequences[f]), key=lambda t: t[0])
+        ret[f] = bytes()
+        for t in seq:
+            if t[0] in seen:
+                continue
+            seen.add(t[0])
+            if t[0] != ofs:
+                print("Gap in %s at %u" % (f, ofs))
+            ret[f] += t[1]
+            ofs = t[0]+len(t[1])
+
+    mestate.mlog.rewind()
+    return ret
+
+def cmd_file(args):
+    '''show files'''
+    files = extract_files()
+    if len(args) == 0:
+        # list
+        for n in sorted(files.keys()):
+            print("%s (length %u)" % (n, len(files[n])))
+        return
+    fname = args[0]
+    if not fname in files:
+        print("File %s not found" % fname)
+        return
+    if len(args) == 1:
+        # print on terminal
+        print(files[fname].decode('utf-8'))
+    else:
+        # save to file
+        dest = args[1]
+        open(dest, "wb").write(files[fname])
+        print("Saved %s to %s" % (fname, dest))
+
 def set_vehicle_name():
     mapping = { mavutil.mavlink.MAV_TYPE_GROUND_ROVER : "Rover",
                 mavutil.mavlink.MAV_TYPE_FIXED_WING : "ArduPlane",
@@ -777,7 +828,7 @@ def set_vehicle_name():
 
 def cmd_param(args):
     '''show parameters'''
-    verbose = False
+    verbose = mestate.settings.paramdocs
     if len(args) > 0:
         if args[0] == 'help':
             set_vehicle_name()
@@ -790,9 +841,12 @@ def cmd_param(args):
             set_vehicle_name()
             mestate.param_help.param_check(mestate.mlog.params, args[1:])
             return
+        if args[0] == 'show':
+            # habits from mavproxy
+            cmd_param(args[1:])
+            return
         wildcard = args[0]
         if len(args) > 1 and args[1] == "-v":
-            set_vehicle_name()
             verbose = True
     else:
         wildcard = '*'
@@ -801,6 +855,7 @@ def cmd_param(args):
         if fnmatch.fnmatch(str(p).upper(), wildcard.upper()):
             s = "%-16.16s %f" % (str(p), mestate.mlog.params[p])
             if verbose:
+                set_vehicle_name()
                 info = mestate.param_help.param_info(p, mestate.mlog.params[p])
                 if info is not None:
                     s += " # %s" % info
@@ -846,7 +901,8 @@ def cmd_devid(args):
     params = mestate.mlog.params
     k = sorted(params.keys())
     for p in k:
-        if p.startswith('COMPASS_DEV_ID') or p.startswith('COMPASS_PRIO'):
+        if p.startswith('COMPASS_DEV_ID') or p.startswith('COMPASS_PRIO') or (
+                p.startswith('COMPASS') and p.endswith('DEV_ID')):
             mp_util.decode_devid(params[p], p)
         if p.startswith('INS_') and p.endswith('_ID'):
             mp_util.decode_devid(params[p], p)
@@ -955,6 +1011,21 @@ def input_loop():
             sys.exit(1)
         mestate.input_queue.put(line)
 
+new_matplotlib = False
+mversion = matplotlib.__version__.split('.')
+matplotlib_major = mversion[0]
+matplotlib_minor = mversion[1]
+if int(matplotlib_major) > 3:
+    new_matplotlib = True
+elif (int(matplotlib_major) >= 3 and int(matplotlib_minor) >= 5):
+    new_matplotlib = True
+
+def epoch_time(num):
+    '''converts a number into an epoch time - compatability wrapper'''
+    if new_matplotlib:
+        return matplotlib.dates.num2date(num).timestamp()
+    return matplotlib.dates.num2epoch(num)
+
 def main_loop():
     '''main processing loop, display graphs and maps'''
     global grui, xlimits
@@ -979,10 +1050,10 @@ def main_loop():
                 xlimits.last_xlim = xlim
                 from dateutil.tz import tzlocal
                 localtimezone = tzlocal()
-                tbase = matplotlib.dates.num2epoch(xlim[0])
+                tbase = epoch_time(xlim[0])
                 tzofs = localtimezone.utcoffset(datetime.datetime.utcfromtimestamp(tbase)).total_seconds()
-                xlimits.xlim_low = matplotlib.dates.num2epoch(xlim[0]) - tzofs
-                xlimits.xlim_high = matplotlib.dates.num2epoch(xlim[1]) - tzofs
+                xlimits.xlim_low = epoch_time(xlim[0]) - tzofs
+                xlimits.xlim_high = epoch_time(xlim[1]) - tzofs
                 
                 if mestate.settings.sync_xmap:
                     remlist = []
@@ -1020,6 +1091,7 @@ command_map = {
     'stats'      : (cmd_stats,     'show statistics on the log'),
     'magfit'     : (cmd_magfit,    'fit mag parameters to WMM'),
     'dump'       : (cmd_dump,      'dump messages from log'),
+    'file'       : (cmd_file,      'show files'),
     }
 
 def progress_bar(pct):
